observed_arrival_nanos

Function observed_arrival_nanos 

pub fn observed_arrival_nanos(
    event_nanos: i64,
    distance: &Quantity,
) -> Option<i64>
The instant (nanoseconds since the epoch) at which an event happening at event_nanos is observed by someone a distance away — event + distance/c. The relativistic light-delay the space-travel time model is built on. None if distance is not a length or the result overflows.