pub fn time_quantity_to_nanos(q: &Quantity) -> Option<i64>Expand description
Convert a Time-dimensioned quantity to a whole number of nanoseconds (rounded to the nearest),
the bridge from the exact Quantity world to the instant model. None if q is not a time, or
the result does not fit i64.